@@ -170,24 +170,38 @@ QVariant MsgListModel::data( const QModelIndex& proxyIndex, int role ) const
 
     switch ( role ) {
         case Qt::ToolTipRole:
-			// No need for tooltips on Maemo
-			return QVariant();
+            switch ( proxyIndex.column() ) {
+                case SUBJECT:
+                    return QAbstractProxyModel::data( proxyIndex, Qt::DisplayRole );
+                case FROM:
+                    return Imap::Message::MailAddress::prettyList(
+                        message->envelope( static_cast<Model*>( sourceModel() ) ).from,
+                                           Imap::Message::MailAddress::FORMAT_READABLE );
+                case TO:
+                    return Imap::Message::MailAddress::prettyList(
+                        message->envelope( static_cast<Model*>( sourceModel() ) ).to,
+                                           Imap::Message::MailAddress::FORMAT_READABLE );
+                case DATE:
+                    return message->envelope( static_cast<Model*>( sourceModel() ) ).date;
+                case SIZE:
+                    return PrettySize::prettySize( message->size( static_cast<Model*>( sourceModel() ) ) );
+                default:
+                    return QVariant();
+            }
         case Qt::DisplayRole:
             switch ( proxyIndex.column() ) {
                 case SUBJECT:
                     return QAbstractProxyModel::data( proxyIndex, Qt::DisplayRole );
                 case FROM:
                     return Imap::Message::MailAddress::prettyList(
-                            message->envelope( static_cast<Model*>( sourceModel() ) ).from,
-                            role == Qt::DisplayRole ? Imap::Message::MailAddress::FORMAT_JUST_NAME : Imap::Message::MailAddress::FORMAT_READABLE );
+                        message->envelope( static_cast<Model*>( sourceModel() ) ).from,
+                                           Imap::Message::MailAddress::FORMAT_JUST_NAME );
                 case TO:
                     return Imap::Message::MailAddress::prettyList(
-                            message->envelope( static_cast<Model*>( sourceModel() ) ).to,
-                            role == Qt::DisplayRole ? Imap::Message::MailAddress::FORMAT_JUST_NAME : Imap::Message::MailAddress::FORMAT_READABLE );
+                        message->envelope( static_cast<Model*>( sourceModel() ) ).to,
+                                           Imap::Message::MailAddress::FORMAT_JUST_NAME );
                 case DATE:
-                {
                     return message->envelope( static_cast<Model*>( sourceModel() ) ).date;
-                }
                 case SIZE:
                     return PrettySize::prettySize( message->size( static_cast<Model*>( sourceModel() ) ) );
                 default:
